/*-------------------------------------------------------------------------
 *
 * scansup.h--
 *	  scanner support routines.  used by both the bootstrap lexer
 * as well as the normal lexer
 *
 * Copyright (c) 1994, Regents of the University of California
 *
 * $Id: scansup.h,v 1.4 1997/11/26 01:14:18 momjian Exp $
 *
 *-------------------------------------------------------------------------
 */

#ifndef SCANSUP_H
#define SCANSUP_H

extern char *scanstr(char *s);

#endif							/* SCANSUP_H */
